@@ -38,6 +38,8 @@ class BuilderForCreateProfile:
             'block': Completely block the 3D API
             'off': Turn off the spoofing, use the original settings
         :param string value: WebGL spoofing type. Possible values: 'noise', 'block', 'off'
+        :param options: Provide unmasked_vendor and unmasked_renderer
+        :type options: ~kameleo.local_api_client.models.WebglSpoofingOptions
         """
         self.profile_request.webgl.value = value
         self.profile_request.webgl.extra = options
@@ -49,7 +51,7 @@ class BuilderForCreateProfile:
             'manual': Timezone is manually overridden in the profile
             'off': Turn off the spoofing, use the original settings
         :param string value: Timezone spoofing type. Possible values: 'automatic', 'manual', 'off'
-        :param TimezoneSpoofingOptions options: When the Timezone spoofing is set to manual the timezone in Iana format is required. For example: America/Grenada
+        :param str options: When the Timezone spoofing is set to manual the timezone in Iana format is required. For example: America/Grenada
         """
         self.profile_request.timezone.value = value
         self.profile_request.timezone.extra = options
@@ -62,6 +64,8 @@ class BuilderForCreateProfile:
             'block': Completely block the GeolocationAPI
             'off': Turn off the spoofing, use the original settings
         :param string value: Geolocation spoofing type. Possible values: 'automatic', 'manual', 'block', 'off'
+        :param options: When the Geolocation spoofing is set to manual the Geolocation coordinates must be provided
+        :type options: ~kameleo.local_api_client.models.GeolocationSpoofingOptions
         """
         self.profile_request.geolocation.value = value
         self.profile_request.geolocation.extra = options
@@ -74,6 +78,8 @@ class BuilderForCreateProfile:
             'socks5': Use a SOCKS5 proxy for upstream communication.</para>
             'ssh': Use an SSH connection for upstream communication. Basically a SOCKS5 proxy created at the given SSH host.</para>
         :param string value: Proxy connection type. Possible values: 'none', 'http', 'socks5', 'ssh'
+        :param options: When the Proxy connection is set, a Proxy Server must be provided
+        :type options: ~kameleo.local_api_client.models.Server
         """
         self.profile_request.proxy.value = value
         self.profile_request.proxy.extra = options
@@ -86,6 +92,8 @@ class BuilderForCreateProfile:
             'block': Block the WebRTC functionality
             'off': Turn off the spoofing, use the original settings
         :param string value: WebRTC spoofing type. Possible values: 'automatic', 'manual', 'block', 'off'
+        :param options: When the WebRTC spoofing is set to manual, the private_ip and public_ip must be provided
+        :type options: ~kameleo.local_api_client.models.WebRtcSpoofingOptions
         """
         self.profile_request.web_rtc.value = value
         self.profile_request.web_rtc.extra = options
@@ -96,6 +104,8 @@ class BuilderForCreateProfile:
             'enabled': Enable fonts spoofing. A list can be provided to override the fonts coming from the base profile.
             'disable': Disable fonts spoofing.
         :param string value: Fonts spoofing type. Possible values: 'enabled', 'disabled'
+        :param options: When the Font spoofing is set to enabled, a list can be provided to overrider the fonts coming from the base profile.
+        :type options: list[str]
         """
         self.profile_request.fonts.value = value
         self.profile_request.fonts.extra = options
@@ -106,6 +116,8 @@ class BuilderForCreateProfile:
             'enabled': Enable plugins spoofing. A list can be provided to EXCLUDE plugins from the plugins of the base profile.
             'disable': Disable plugins spoofing.
         :param string value: Plugins spoofing type. Possible values: 'enabled', 'disabled'
+        :param options: When the Plugins spoofing is set to enabled, a list can be provided to EXCLUDE plugins from the plugins of the base profile.
+        :type options: list[str]
         """
         self.profile_request.plugins.value = value
         self.profile_request.plugins.extra = options
@@ -113,6 +125,7 @@ class BuilderForCreateProfile:
 
     def set_start_page(self, value):
         """This website will be opened in the browser when the profile launches.
+        :param string value: The url of the start page
         """
         self.profile_request.start_page = value
         return self
@@ -132,6 +145,7 @@ class BuilderForCreateProfile:
             'manual': Manually override the screen resolution.
             'off': Turn off the spoofing, use the original settings.
         :param string value: Screen spoofing type. Possible values: 'automatic', 'manual', 'off'
+        :param string options: When the Screen spoofing is set to manual, the required screen size must be provided. For example: 1080x1920
         """
         self.profile_request.screen.value = value
         self.profile_request.screen.extra = options
@@ -139,6 +153,8 @@ class BuilderForCreateProfile:
 
     def set_extensions(self, absolute_paths):
         """A list of absolute paths from where the profile should load extensions or addons when starting the browser. For chrome and edge use CRX3 format extensions. For firefox use signed xpi format addons.
+        :param absolute_paths: A list of abolute paths from where the profile should load extensions or addons when starting the browser.
+        :type absolute_paths: list[str]
         """
         self.profile_request.extensions = absolute_paths
         return self
